#!/usr/bin/perl
#$Id: plot_gas.pl,v 1.25 2019/05/11 07:02:24 rig1 Exp $
use strict;
use warnings;
use RFC::Rig;
use RFC::Main;
use DateTime;
sleep(30) unless (@ARGV > 1);
my $rig = RFC::Rig->new(shift);
$rig->check_run();

my %months = (
    '01' => 'January',
    '02' => 'February',
    '03' => 'March',
    '04' => 'April',
    '05' => 'May',
    '06' => 'June',
    '07' => 'July',
    '08' => 'August',
    '09' => 'September',
    '10' => 'October',
    '11' => 'November',
    '12' => 'December',
    );


my $dt = DateTime->now(time_zone=>'local');
$dt->truncate( 'to' => 'month' );
my $dt2 = $dt;
$dt2->subtract( 'days' => 2);
my $str = scalar($dt);
$str =~ /([\d\-]+)/;
my $start = $1;
$start =~ s/\-/:/g;
my $end = $start;
$end =~ s/01$/31/;
$start =~ /(\d+)\:(\d+)/;
my $tit = $months{$2}.' '.$1;


$str = scalar($dt);
$str =~ /([\d\-]+)/;
my $start2 = $1;
$start2 =~ s/\-/:/g;

my $GNUPLOT = &get_cv('GNUPLOT','location');
my $secondary = $rig->get_cv('gasmon','plot_on_secondary_y');

my $dir = $rig->webdir();
my $outfile = $dir.'data.'.$start;
open OUT,'>',$outfile or die "Could not open file $outfile for writing: $!\n";
opendir (DIR,$dir) or die $!;
my $head = '';
my $startfile = 'raadata.'.$start2;
my @flist = ();
while (my $file = readdir(DIR))
{
    next unless ($file =~ /raadata/ && $file =~ /\d+/);
    next if ($file le $startfile);
    my $f = $dir.'/'.$file;
    push @flist,$f;
}
foreach my $f (sort {$a cmp $b} @flist)
{
    open MYIN,'<',$f or die "Could not open file $f $!\n";
    while (my $line = <MYIN>)
    {
	$head = $line unless ($head);
	print OUT $line;
    }
    close MYIN;
} 
close OUT;

my @list = $rig->get_cv('gasmon','cols_to_plot');
exit unless (@list);
my %ids = ();
my @cols = split(/\s+/,$head);
foreach my $g (@list)
{
    for (my $x = 0; $x < @cols; $x++)
    {
	next unless ($cols[$x] eq $g);
	$ids{$g} = $x+4;
	last;
    }
}
my $plotcmd;
my $plotcmd2;
my $time = time() - 12 * 60 * 60;
my $bgcolr = 'black';
my $lcolor = 'white';
my @linetypes = ('lt 1','lt 2','lt 3','lt 4','lt 5','lt 6','lt 8','lt 9','lt 10','lt 11','lt 12','lt 13','lt 14','lt 15','lt 16','lt 18','lt 19','lt 20');
if ($rig->get_cv('gasmon','background_color') && $rig->get_cv('gasmon','') !~ /black/)
{
    my $bgcolr = 'white';
    my $lcolor = 'black';
    my @linetypes = ('lt 1','lt 2','lt 3','lt 4','lt 5','lt 7','lt 8','lt 9','lt 10','lt 11','lt 12','lt 13','lt 14','lt 15','lt 17','lt 18','lt 19','lt 20');
}
#my @linetypes = ('lt 1','lt 2','lt 3','lt 4','lt 5','lt 6','lt 8','lt 9','lt 10 dt 1','lt 11 dt 1','lt 12 dt 1','lt 13 dt 1','lt 14 dt 1','lt 15 dt 1','lt 16 dt 1','lt 18 dt 1','lt 19 dt 1','lt 20 dt 1');
my $ltcount = 0;
foreach my $key (@list)
{
    my $lt = $linetypes[$ltcount++];
    my $col = $ids{$key};
    my $axis = '';
    my $title = $rig->get_cv('gasmon','tag_title_'.$key);
    $title = $key unless ($title);
    $title =~ s/_/ /g;
    if ($secondary =~ /$key/)
    {
	$axis = 'axis x1y2';
	$title .= ' ->';
    }
    if ($plotcmd)
    {
	$plotcmd .= ",'' u (g(strcol(2))):(f(\$$col)) $axis w lines $lt tit '$title'";
    }
    else
    {
	$plotcmd = "plot '$outfile' u (g(strcol(2))):(f(\$$col)) $axis w lines $lt tit '$title'";
    }
    if ($plotcmd2)
    {
	$plotcmd2 .= ",'' u (g(strcol(2))):(f(\$$col)) $axis w lines $lt tit '$title'";
    }
    else
    {
	$plotcmd2 = "plot \"<awk '\$3 > $time' $outfile\" u (g(strcol(2))):(f(\$$col)) $axis w lines $lt tit '$title'";
    }
}

my $ylabel = $rig->get_cv('gasmon','ylabel');
my $y2label = $rig->get_cv('gasmon','y2label');
my $yrange = $rig->get_cv('gasmon','yrange');
my $y2range = $rig->get_cv('gasmon','y2range');
$ylabel = 'Pressure (Bar)' unless ($ylabel);
$y2label = 'Pressure (Bar)' unless ($y2label);
$yrange = '[0:250]' unless ($yrange);
$y2range = '[0:25]' unless ($y2range);


my $gp = $dir.'gas.gp';
my $png = $dir.'/../'.$start.'.png';
my $png2 = $dir.'/../current.png';
open GP,'>',$gp or die "Could not open file $gp for writing: $!\n";
print GP <<END;





g(x) = strptime("%Y:%m:%d:%H:%M:%S",x)>strptime("%Y:%m:%d",'$start')?x:1/0;

#set term pngcairo background rgb '#2c3431' size 1024,480
set term pngcairo background rgb '$bgcolr' size 1024,480
set style fill solid 1.0 noborder
set border lc rgb '$lcolor'
set xdata time
set timefmt "%Y:%m:%d:%H:%M:%S"
set ylabel '$ylabel' tc rgb '$lcolor'
set y2label '$y2label' tc rgb '$lcolor'
set yrange $yrange
set y2range $y2range
f(x) = x>0?x:1/0
set key textcolor rgb '$lcolor'
set xtics nomirror tc rgb '$lcolor'
set ytics nomirror tc rgb '$lcolor'
set y2tics nomirror tc rgb '$lcolor'
set key font ",16"
set key spacing 1.5
set key width 5

set key top left Left
set out '$png2'
set format x "%H:%M"
set xlabel 'Time' tc rgb '$lcolor'
$plotcmd2

set key top right Left
set out '$png'
set title '$tit' tc rgb '$lcolor'
set xrange ['$start:00:00':'$end:23:59']
set format x "%d"
set xlabel 'Date' tc rgb '$lcolor'
$plotcmd


END

close GP;

my $cmd = $GNUPLOT. ' '.$gp;
system($cmd);
unlink $gp if (-e $gp);
