#!/usr/bin/perl
use strict;
use warnings;
use CGI qw(:standard :netscape);
use RFC::Rig;
use RFC::RFCCGI qw(:cgi :html);
use RFC::Header;
use Sys::Hostname;

my $hostname = hostname();
my $r = param('rig');
my $kiosk = param('kiosk');
unless ($r)
{
    print header();
    print "No rig specified!\n";
    exit;
}
my $rig = RFC::Rig->new($r);
my $file = '/rig'.$r.'/current.png';

my $str = $rig->get_cv('gasmon','header');
if ($str)
{
    print_header($str);
}
else
{
    print_header("Gas monitoring system $hostname");
}
print '<link rel="stylesheet" type="text/css" href="/gasmon.css" />',"\n";
print '<center>';
if ($str)
{
    print h1($str);
}
else
{
    print h1("Gas monitoring for $hostname");
}


print p('<img id=current_data src="" alt="Graph of pressures for last 12 hours"></img>');
print h1({-class=>'Alert',-id=>'warning_notice'},'Warning: Data not synchronised!');
print '<table class=status_display><tr>';
my @list = $rig->get_cv('gasmon','dual_gas_list');
foreach my $n (@list)
{
    print '<td>';
    my $tit = $rig->get_cv('gasmon','tag_title_'.$n);
    $tit = $n unless ($tit);
    $tit =~ s/_/ /g;
    print button(-id=>$n,-value=>$tit,-class=>'ok');
    print '</td>';
}
print '</tr><tr>';
my @single = $rig->get_cv('gasmon','single_gas_list');
foreach my $n (@single)
{
    print '<td>';
    my $tit = $rig->get_cv('gasmon','tag_title_'.$n);
    $tit = $n unless ($tit);
    $tit =~ s/_/ /g;
    print button(-id=>$n,-value=>$tit,-class=>'ok');
    print '</td>';
}
print '</tr><tr>';
my @remote;
foreach my $n ($rig->get_cv('gasmon','remote_list_display'))
{
    my $server = $rig->get_cv('gasmon','server_'.$n);
    next unless ($server);
    print '<td>';
    my $tit = $rig->get_cv('gasmon','tag_title_'.$n);
    $tit = $n unless ($tit);
    $tit =~ s/_/ /g;
    my ($host,$rr) = split('#',$server);
    print start_form(-action=>'https://'.$host.'/cgi-bin/gasmon/show_data.cgi');
    print hidden(-name=>'rig',-value=>$rr,-force=>1);
    print submit(-id=>$n,-value=>$tit,-class=>'ok');
    print end_form();
    print '</td>';
    push @remote,$n.'#'.$server;
}
print hidden(-id=>'single_list',-value=>join(',',@list,@single),-force=>1);
print hidden(-id=>'remote_list',-value=>join(',',@remote),-force=>1);

print '</tr></table>';
print '<h1 id=notice class=Alert></h1>';

print h1('<a href="old_data.cgi?rig='.$r.'">Old data</a>  <a href="/rig'.$r.'/">All data</a> <a href="../celltest/prelogin.cgi">Configure</a>') unless ($kiosk);
print '</center>';

print start_form(-name=>'reload');
print hidden(-name=>'rig',-value=>$r,-force=>1);
print hidden(-name=>'kiosk',-value=>$kiosk,-force=>1);
print end_form();

print <<END;

<script>

function set_warning()
{
    document.getElementById('warning_notice').style.display = 'block';
}

function hide_warning()
{
    document.getElementById('warning_notice').style.display = 'none';
}

function reloadImage()
{
    img = document.getElementById('current_data');
    img.src = '$file?' + Math.random();
    setTimeout("reloadImage()", 120000);
}

reloadImage();
setTimeout(get_status,1000);
setTimeout(reload_page,3600000);
var timeid;
var remaining = 0;

function reload_page()
{
    document.reload.submit();
}

function check_remaining()
{
    if (remaining < 1)
    {
	clearTimeout(timeid);
	hide_warning();
    }
}

function get_status()
{
    remaining = 0;
    timeid = setTimeout(set_warning,30000);
    var list = document.getElementById('single_list').value.split(',');
    for (var x = 0; x < list.length;x++)
    {
	if (list[x] != null && list[x] != '')
	{
	    run_ajax('ajax.cgi','&action=check_status&rig=$r&device='+list[x],set_status);
	    remaining++;
	}
    }
    list = document.getElementById('remote_list').value.split(',');
    for (var x = 0; x < list.length;x++)
    {
	if (list[x] != null && list[x] != '')
	{
	    var a = list[x].split('#');
	    var query ='&action=check_status&rig='+a[2]+'&device='+a[0];
	    run_ajax('https://'+a[1]+'/cgi-bin/gasmon/ajax.cgi',query,set_status);
	    remaining++;
	}
    }
    setTimeout("get_status()",120000);
}

function set_status(res)
{
    var arr = res.split(/\\n/);
    if (arr[0] == 'OK')
    {
	remaining--;
	var e = document.getElementById(arr[1]).className = arr[2];
	check_remaining();
	return true;
    }
    else
    {
	set_warning();
    }
}

</script>

END

print end_html;
